@@ -1,3 +1,4 @@
+from datetime import datetime
 from typing import List, Union
 
 from bigquery.job.ems_job import EmsJob
@@ -10,8 +11,9 @@ class EmsExtractJob(EmsJob):
                  table: str,
                  destination_uris: List[str],
                  state: EmsJobState,
-                 error_result: Union[dict, None]):
-        super(EmsExtractJob, self).__init__(job_id, state, error_result)
+                 error_result: Union[dict, None],
+                 created: datetime = None):
+        super(EmsExtractJob, self).__init__(job_id, state, error_result, created)
 
         self.__table = table
         self.__destination_uris = destination_uris
